# Copyright (c) 2000-2010, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

Name:           hatbox
Version:        1.0
Release:        0.b7.1%{?dist}
Summary:        User-space spatial add-on for Derby and H2 databases

Group:          Development/Libraries
License:        LGPL
URL:            http://hatbox.sourceforge.net/

Source0:        hatbox-1.0.b7.tgz
# svn export http://hatbox.svn.sourceforge.net/svnroot/hatbox/hatbox hatbox-1.0.b7
# rm -rf hatbox-1.0.b7/tags
# tar czf hatbox-1.0.b7.tgz hatbox-1.0.b7/

Source1:        %{name}-settings.xml
Source2:        %{name}-jpp-depmap.xml 
# patch these files to JDBC 4.0
Patch0:         hatbox-IdResultSetMetaData.patch
Patch1:         hatbox-IdResultSet.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  jpackage-utils >= 0:1.7.5
BuildRequires:  java-devel >= 0:1.6.0
BuildRequires:  maven2 >= 0:2.0.8
BuildRequires:  maven2-plugin-compiler
BuildRequires:  maven2-plugin-jar
BuildRequires:  maven2-plugin-javadoc
BuildRequires:  maven2-plugin-source
BuildRequires:  maven-surefire-maven-plugin
BuildRequires:  maven-surefire-provider-junit4
BuildRequires:  apache-commons-parent
BuildRequires:  junit44
BuildRequires:  h2database
BuildRequires:  jts-topo-suite

Requires:  java >= 0:1.6.0
Requires:  jpackage-utils >= 0:1.7.5
Requires:  h2database
Requires:  jts-topo-suite

Requires(post):    jpackage-utils >= 0:1.7.5
Requires(postun):  jpackage-utils >= 0:1.7.5

BuildArch:      noarch

%description
'user-space add-on' what does that mean? It means that 
HatBox employs user visible tables, procedures, functions 
and triggers to implement spatial functionality on top of 
standard Derby/JavaDB and H2. The upside is that when you 
use HatBox you are not tied to a special version of Derby 
or H2, you can upgrade Derby and H2 independently of 
HatBox. The down side is that feature geometry must be 
created and manipulated outside the database and the 
tables, procedures, functions and triggers that make up 
HatBox may be corrupted by inadvertent user action. This 
approach was taken to avoid deep modification of the Derby 
and H2 code bases, and to avoid sticky source licensing 
issues, particularly in respect of the JTS Topology Suite. 
JTS is a critical library for Hatbox, supplying all the 
secondary filtering functionality. It is licensed under 
the LGPL, which is incompatible with the licences of 
Apache Derby (ASL 2.0) and H2 (MPL 1.1 and EPL 1.0)

%package javadoc 
Summary:        Javadocs for %{name} 
Group:          Documentation 
Requires:       %{name} = %{version}-%{release} 
 
%description javadoc 
%{summary}. 

%prep
%setup -q -n hatbox-1.0.b7
cp -p %{SOURCE1} settings.xml
sed -i -e "s|<url>__JPP_URL_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__JAVADIR_PLACEHOLDER__</url>|<url>file://`pwd`/external_repo</url>|g" settings.xml
sed -i -e "s|<url>__MAVENREPO_DIR_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__MAVENDIR_PLUGIN_PLACEHOLDER__</url>|<url>file:///usr/share/maven2/plugins</url>|g" settings.xml
%patch0 -b .sav0
%patch1 -b .sav1
mkdir external_repo
ln -s %{_javadir} external_repo/JPP

%build
export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository
mkdir -p ${MAVEN_REPO_LOCAL}

export MAVEN_OPTS="-Dmaven2.jpp.mode=true -Dmaven2.jpp.depmap.file=%{SOURCE2} -Dmaven.repo.local=${MAVEN_REPO_LOCAL} -Djava.awt.headless=true -Daggregate=true"
export MAVEN_SETTINGS=$(pwd)/settings.xml
%{_bindir}/mvn-jpp \
        -e \
        -s ${MAVEN_SETTINGS} \
        install javadoc:javadoc

%install
%__rm -rf %{buildroot}

# jar
%__mkdir_p %{buildroot}%{_javadir}
%__install -m 644 target/hatbox-1.0.b7.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{version}*; do \
%__ln_s ${jar} ${jar/-%{version}/}; done)

# poms
%__mkdir_p %{buildroot}%{_datadir}/maven2/poms
%__install -m 644 pom.xml \
               $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}.pom
%add_to_maven_depmap net.sourceforge.hatbox %{name} %{version} JPP %{name}

# javadoc 
%__mkdir_p %{buildroot}%{_javadocdir}/%{name}-%{version} 
%__cp -a target/site/apidocs/* \
               %{buildroot}%{_javadocdir}/%{name}-%{version}
%__ln_s %{name}-%{version} %{buildroot}%{_javadocdir}/%{name} 

%clean
%__rm -rf %{buildroot}

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%defattr(-,root,root,-)
%{_javadir}/*.jar
%{_datadir}/maven2/poms/*
%{_mavendepmapfragdir}/*

%files javadoc 
%defattr(-,root,root,-) 
%{_javadocdir}/%{name}-%{version} 
%{_javadocdir}/%{name} 

%changelog
* Fri Oct 15 2010 Ralph Apel <r.apel@r-apel.de> 1.0-0.b7.1
- First release

